@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2014
+* (C) Francesco Mondello 2009-2015
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -99,7 +99,9 @@ MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
 
     resetDisplays();
 
-    checkForUpdates();
+    if (IniSettings::isAutoChechUpdates()) {
+        checkForUpdates();
+    }
 
     checkVersion();
 }
@@ -203,12 +205,13 @@ void MainWindowImpl::createContextMenu()
 void MainWindowImpl::openFiles()
 {
     iAList->clear();
-    CachingSystem::clear();
     addFiles();
 }
 
 void MainWindowImpl::addFiles()
 {
+    CachingSystem::clear();
+
     QString path = IniSettings::latestOpenedDir();
 
     QString readableFiltersString = Formats::readableFiltersString();
@@ -894,11 +897,21 @@ void MainWindowImpl::checkVersion()
     int currentVersion = globals::CURRENT_INTERNAL_VERSION;
 
     if (savedVersion < currentVersion) {
-		QString welcomePage = QString("http://fasterland.net/redirects/welcome.php?product=converseen&version=%1")
-			.arg(globals::VERSION);
+	        QString appVersion;
 
-        QDesktopServices::openUrl(QUrl(welcomePage, QUrl::TolerantMode));
-        IniSettings::setCurrentVersion(currentVersion);
+    #ifdef Q_OS_WIN32
+        appVersion = QString("%1%2")
+                .arg(QCoreApplication::applicationVersion())
+                .arg(globals::Globals::signature());
+    #else
+        appVersion = QCoreApplication::applicationVersion();
+    #endif
+
+	QString welcomePage = QString("http://fasterland.net/redirects/welcome.php?product=converseen&version=%1")
+            .arg(appVersion);
+
+    QDesktopServices::openUrl(QUrl(welcomePage, QUrl::TolerantMode));
+    IniSettings::setCurrentVersion(currentVersion);
     }
 }
 
@@ -1008,15 +1021,13 @@ void MainWindowImpl::openPaypalLink()
 
 void MainWindowImpl::openFlattrLink()
 {
-    QDesktopServices::openUrl(QUrl("http://converseen.fasterland.net/#donations", QUrl::TolerantMode));
+    QDesktopServices::openUrl(QUrl("http://flattr.com/thing/3332139/Converseen", QUrl::TolerantMode));
 }
 
 void MainWindowImpl::checkForUpdates()
 {
-    if (IniSettings::isAutoChechUpdates()) {
-        UpdateChecker *up = new UpdateChecker();
-        up->checkForUpdates();
-    }
+    UpdateChecker *up = new UpdateChecker();
+    up->checkForUpdates();
 }
 
 void MainWindowImpl::bugReport()
